/**
 * Copyright © 2025 IAV GmbH Ingenieurgesellschaft Auto und Verkehr, All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * SPDX-License-Identifier: Apache-2.0
 */

import React, { useContext, useState } from "react";
import { Link } from "react-router-dom";
import { BLUE3, PADDING_GAB, WHITE } from "../../../constants";
import { AuthContext } from "../../../contexts/auth";
import { LoginButtonWithSpinner } from "../loginButtonWithSpinner";
import { useTranslator } from "../../internationalization/translators";
import "../authenticationView.css";
import "../../css/globalColors.css";
import loginBackgroundLightMode from "../../../assets/png/login_background_lightMode.png";
import loginBackgroundDarkMode from "../../../assets/png/login_background_darkMode.png";
import { Dropdown } from "primereact/dropdown";
import { LanguageContext } from "../../../contexts/language";
import { parseLanguageResourcesIntoDropdownFormat } from "../../../utils/parseLanguageResourcesIntoDropdownFormat";
import { ColorSettingsContext } from "../../../contexts/colorsettings";
import { generateHashOfLength } from "../../../utils/hash";
import { Tooltip } from "primereact/tooltip";
import { AppLogoPlaceholder } from "../../appLogoPlaceholder";
import CompanyLogo from "../../../assets/svg/companyLogo";
export const AWSAuthenticationView = props => {
  const [email, setEmail] = useState("");
  const [password, setPassword] = useState("");
  const langContext = useContext(LanguageContext);
  const colorSettingsContext = useContext(ColorSettingsContext);
  const authContext = useContext(AuthContext);
  const t = useTranslator();
  const passwortRequirementsTextColor = colorSettingsContext.currentColors.authenticationView.passwortRequirementsTextColor;
  const inputFieldDescriptionTextColor = colorSettingsContext.currentColors.authenticationView.inputFieldDescriptionTextColor;
  const inputFieldBackgroundColor = colorSettingsContext.currentColors.authenticationView.inputFieldBackgroundColor;
  const inputFieldTextColor = colorSettingsContext.currentColors.authenticationView.inputFieldTextColor;
  const headerBackgroundColor = colorSettingsContext.currentColors.authenticationView.headerBackgroundColor;
  const fullScreenBackgroundColor = colorSettingsContext.currentColors.authenticationView.fullScreenBackgroundColor;
  const loginFormBackgroundColor = colorSettingsContext.currentColors.authenticationView.loginFormBackgroundColor;
  const legalNoticeIconColor = colorSettingsContext.currentColors.authenticationView.legalNoticeIconColor;
  const companyTextColor = colorSettingsContext.currentColors.authenticationView.companyTextColor;
  const themeTogglerColor = colorSettingsContext.currentColors.authenticationView.themeTogglerColor;
  const submit = event => {
    event.preventDefault();
    if (authContext?.isNewPasswordRequired) {
      authContext?.completePassword(password);
    } else {
      authContext?.login({
        email: email,
        password: password
      });
    }
  };
  const getErrorText = error => {
    if (error) {
      if (typeof error === "object") {
        if (error.code) {
          if (error.code === "UserGroupError") {
            return t("invalid_access_configuration"); // user was not added to a group
          } else if (error.code === "NotAuthorizedException") {
            return t("invalid_username_or_password"); // invalid user credentials
          } else if (error.code === "InvalidPasswordException") {
            return t("password_requirements_not_met"); // set password does not conform to password policy
          } else {
            return t("server_error");
          }
        } else if (error.message) {
          if (error.message === "UserGroupError") {
            return t("invalid_access_configuration");
          }
          return error.message;
        }
      } else {
        return t("server_error");
      }
    }
    return "";
  };
  const companyLogoDefault = props => /*#__PURE__*/React.createElement("div", {
    style: {
      display: props.headerOptions?.hideRight ? "none" : "flex",
      alignItems: "center",
      paddingRight: `${PADDING_GAB}px`
    }
  }, /*#__PURE__*/React.createElement(CompanyLogo, {
    fill: colorSettingsContext?.darkmode ? BLUE3 : WHITE
  }));
  const NewPasswordForm = /*#__PURE__*/React.createElement("div", {
    style: {
      width: "100%",
      height: "100%"
    }
  }, /*#__PURE__*/React.createElement("div", {
    style: {
      margin: "0px 24px 0px 24px"
    },
    className: "flex flex-column"
  }, /*#__PURE__*/React.createElement("div", {
    style: {
      color: passwortRequirementsTextColor
    }
  }, /*#__PURE__*/React.createElement("p", null, t("replace_temporary_password")), /*#__PURE__*/React.createElement("ul", null, /*#__PURE__*/React.createElement("li", null, t("password_req_8_characters")), /*#__PURE__*/React.createElement("li", null, t("password_req_upper_lower_case")), /*#__PURE__*/React.createElement("li", null, t("password_req_special_character")), /*#__PURE__*/React.createElement("li", null, t("password_req_one_digit")))), /*#__PURE__*/React.createElement("form", {
    autoComplete: "off",
    onSubmit: submit
  }, /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement("label", {
    style: {
      fontWeight: "normal",
      marginBottom: "2px",
      fontSize: "12px",
      color: inputFieldDescriptionTextColor
    },
    className: "inputLabel " + (authContext?.loginError ? "invalid" : "")
  }, t("New_password")), /*#__PURE__*/React.createElement("input", {
    name: "password",
    type: "password",
    id: "inputPassword",
    style: {
      marginBottom: "40px",
      width: "100%",
      backgroundColor: inputFieldBackgroundColor,
      color: inputFieldTextColor
    },
    className: "form-control p-inputtext " + (authContext?.loginError ? "invalid" : ""),
    onChange: ev => setPassword(ev.target.value),
    required: true,
    autoFocus: true
  }), /*#__PURE__*/React.createElement(LoginButtonWithSpinner, {
    isLoading: authContext?.isLoading
  }), /*#__PURE__*/React.createElement("div", {
    className: "invalid"
  }, getErrorText(authContext?.loginError))))));
  const LoginForm = /*#__PURE__*/React.createElement("form", {
    style: {
      width: "100%",
      height: "100%"
    },
    onSubmit: submit
  }, /*#__PURE__*/React.createElement("div", {
    style: {
      margin: "40px 24px 0px 24px"
    },
    className: "flex flex-column"
  }, /*#__PURE__*/React.createElement("label", {
    style: {
      fontWeight: "normal",
      marginBottom: "2px",
      fontSize: "12px",
      color: inputFieldDescriptionTextColor
    },
    className: "inputLabel"
  }, t("Email_address")), /*#__PURE__*/React.createElement("input", {
    value: email.valueOf(),
    onChange: ev => setEmail(ev.target.value),
    name: "email",
    type: "email",
    className: "p-inputtext",
    required: true,
    autoFocus: true,
    style: {
      marginBottom: "40px",
      backgroundColor: inputFieldBackgroundColor,
      color: inputFieldTextColor
    }
  }), /*#__PURE__*/React.createElement("label", {
    style: {
      fontWeight: "normal",
      marginBottom: "2px",
      fontSize: "12px",
      color: inputFieldDescriptionTextColor
    },
    className: "inputLabel"
  }, t("Password")), /*#__PURE__*/React.createElement("input", {
    value: password.valueOf(),
    onChange: ev => setPassword(ev.target.value),
    name: "password",
    type: "password",
    className: "p-inputtext",
    required: true,
    style: {
      marginBottom: "40px",
      backgroundColor: inputFieldBackgroundColor,
      color: inputFieldTextColor
    }
  }), /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement(LoginButtonWithSpinner, {
    isLoading: authContext?.isLoading
  })), /*#__PURE__*/React.createElement("div", {
    style: {
      marginTop: "20px"
    },
    className: "invalid"
  }, getErrorText(authContext?.loginError))));
  const header = props => /*#__PURE__*/React.createElement("div", {
    className: "flex justify-content-between",
    style: {
      backgroundColor: headerBackgroundColor,
      color: "white",
      alignItems: "center",
      height: "56px"
    }
  }, /*#__PURE__*/React.createElement("div", {
    id: "left-element-authentication",
    className: "flex align-items-center default-app-logo-text-style"
  }, props.headerOptions?.reactElementLeft ? props.headerOptions?.reactElementLeft : /*#__PURE__*/React.createElement(AppLogoPlaceholder, null)), /*#__PURE__*/React.createElement("div", {
    id: "right-element-authentication",
    className: "flex justify-content-end align-items-center default-app-logo-text-style"
  }, props.headerOptions?.reactElementRight ? props.headerOptions?.reactElementRight : companyLogoDefault(props)));
  const identifier = generateHashOfLength(4);
  const identifierLegal = "a" + identifier;
  const identifierWithDot = "." + identifierLegal;
  return /*#__PURE__*/React.createElement("div", {
    className: "flex",
    style: {
      height: "100%",
      background: "",
      backgroundColor: fullScreenBackgroundColor
    }
  }, colorSettingsContext?.colorOptions.authenticationView?.fullScreenBackgroundColor ? /*#__PURE__*/React.createElement(React.Fragment, null) : /*#__PURE__*/React.createElement("img", {
    style: {
      inset: "0px",
      position: "absolute",
      zIndex: "-100",
      height: "100vh",
      width: "100vw",
      objectFit: "cover"
    },
    src: props.authOptions?.backgroundImage ? props.authOptions?.backgroundImage : colorSettingsContext?.darkmode ? loginBackgroundDarkMode : loginBackgroundLightMode
  }), /*#__PURE__*/React.createElement("div", {
    className: "flex flex-column shadow-6",
    style: {
      width: "620px",
      margin: "auto",
      position: "relative",
      backgroundColor: loginFormBackgroundColor
    }
  }, /*#__PURE__*/React.createElement("div", null, header(props)), /*#__PURE__*/React.createElement("div", {
    className: "flex flex-column",
    style: {
      justifyContent: "center"
    }
  }, /*#__PURE__*/React.createElement("div", {
    style: {
      width: "100%",
      padding: "24px 24px 0px 0px"
    },
    className: "flex align-items-center justify-content-end"
  }, props.authOptions?.preventDarkmode === true ? /*#__PURE__*/React.createElement(React.Fragment, null) : /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement("i", {
    onClick: () => colorSettingsContext?.setDarkmode(!colorSettingsContext.darkmode),
    style: {
      color: themeTogglerColor
    },
    className: `switch-colormode-logos pi ${colorSettingsContext.darkmode ? "pi-moon" : "pi-sun"}`
  })), !props.hideLanguageSelection && /*#__PURE__*/React.createElement(Dropdown, {
    style: {
      width: "160px",
      backgroundColor: inputFieldBackgroundColor,
      color: inputFieldTextColor
    },
    placeholder: langContext?.resources[langContext.activeLang].translation.option_name,
    onChange: function (event) {
      langContext?.selectLanguage(event.value.key);
    },
    options: parseLanguageResourcesIntoDropdownFormat(langContext?.resources),
    optionLabel: "label"
  })), authContext?.isNewPasswordRequired ? NewPasswordForm : LoginForm), !props.hideLegalDocuments && /*#__PURE__*/React.createElement(Link, {
    style: {
      position: "absolute",
      bottom: "12px",
      left: `${PADDING_GAB}px`,
      textDecoration: "none"
    },
    to: "/documents",
    target: "_blank"
  }, /*#__PURE__*/React.createElement("span", {
    className: "pi pi-info-circle " + identifierLegal,
    style: {
      fontSize: "medium",
      fontWeight: "bold",
      color: legalNoticeIconColor
    }
  })), /*#__PURE__*/React.createElement(Tooltip, {
    content: t(props.authOptions?.documentsLabelKey ? props.authOptions?.documentsLabelKey : "Imprint"),
    target: identifierWithDot,
    id: "hover-image"
  }), /*#__PURE__*/React.createElement("span", {
    style: {
      alignSelf: "center",
      padding: "24px",
      fontSize: "11px",
      color: companyTextColor
    }
  }, "\xA9", " ", props.authOptions?.companyText ? props.authOptions?.companyText : "IAV GmbH 2024")));
};